==> ksetisaver_0.3.3.orig.tar.gz: ksetisaver-0.3.3/ksetisaver/setilocation.h <==
/***************************************************************************
                          setilocation.h  -  description
                             -------------------
    begin                : Wed Apr 10 2002
    copyright            : (C) 2002 by Sebastian Schildt
    email                : sebastian@frozenlight.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SETILOCATION_H
#define SETILOCATION_H

/* Deprecated, but on MDK9 it doesn't work without the .h */
#include <iostream.h>

#include <qstring.h>
#include <qfileinfo.h>
#include <qtextstream.h>


/**
  *@author Sebastian Schildt
  */

class SetiLocation {
public: 
	SetiLocation(QString path);
	~SetiLocation();

	enum client_states { RUNNING, STOPPED, FINISHED, CONNECT, TRANSFER, UNKNOWN };
  int getState();
	client_states currentState;

	QString getPath() const;
	void updateProc(double pr);

private:
	QString path;
	QString procPIDPath;
	double proc;
	int pid;

	QFileInfo *wu;
	QFileInfo *wtemp;
	QFileInfo *state;
	QFileInfo *result;
	QFileInfo *reHeader;
	QFileInfo *pidFile;

	bool procIncrease;

	bool isClientRunning();
};

#endif

==> ksetisaver_0.3.4.dfsg1.orig.tar.gz: ksetisaver-0.3.4.dfsg1/ksetisaver/setilocation.h <==
/***************************************************************************
                          setilocation.h  -  description
                             -------------------
    begin                : Wed Apr 10 2002
    copyright            : (C) 2002 by Sebastian Schildt
    email                : sebastian@frozenlight.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SETILOCATION_H
#define SETILOCATION_H

/* Deprecated, but on MDK9 it doesn't work without the .h */
#include <iostream.h>

#include <qstring.h>
#include <qfileinfo.h>
#include <qtextstream.h>


/**
  *@author Sebastian Schildt
  */

class SetiLocation {
public: 
	SetiLocation(QString path);
	~SetiLocation();

	enum client_states { RUNNING, STOPPED, FINISHED, CONNECT, TRANSFER, DATAPATH_NOTFOUND, UNKNOWN };
  int getState();
	client_states currentState;

	QString getPath() const;
	void updateProc(double pr);

private:
	QString path;
	QString procPIDPath;
	double proc;
	int pid;

	QFileInfo *wu;
	QFileInfo *wtemp;
	QFileInfo *state;
	QFileInfo *result;
	QFileInfo *reHeader;
	QFileInfo *pidFile;
	QFileInfo *userFile;

	bool procIncrease;

	bool isClientRunning();
};

#endif
